*******
Install
*******

It can be installed using `pip`_::

  pip install glimix-core

Or using `conda`_::

  conda install -c conda-forge glimix-core

.. _conda: http://conda.pydata.org/docs/index.html
.. _pip: https://pypi.python.org/pypi/pip
